@@ -23,22 +23,21 @@ from aliyunsdkarms.endpoint import endpoint_data
 class ConfigAppRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'ConfigApp')
+		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'ConfigApp','arms')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AppIds(self):
+	def get_AppIds(self): # String
 		return self.get_query_params().get('AppIds')
 
-	def set_AppIds(self,AppIds):
-		self.add_query_param('AppIds',AppIds)
-
-	def get_Enable(self):
+	def set_AppIds(self, AppIds):  # String
+		self.add_query_param('AppIds', AppIds)
+	def get_Enable(self): # String
 		return self.get_query_params().get('Enable')
 
-	def set_Enable(self,Enable):
-		self.add_query_param('Enable',Enable)
\ No newline at end of file
+	def set_Enable(self, Enable):  # String
+		self.add_query_param('Enable', Enable)
